
<h1 align="center">
  <br>
  <a href="https://github.com/dpr1005/Semisupervised-learning-and-instance
-selection-methods"><img src="./misc/logo.png" 
alt="ISMSSL by DNX"></a>
  <br>
  Semi-supervised learning → Instance Selection Methods 
  <br>
</h1>

<h4 align="center">Instance selection methods for semi-supervised learning.</h4>



<p align="center">
  <a href="#key-features">Key Features</a> •
  <a href="#setup">Setup</a> •
  <a href="#usage-guide">Usage guide</a> •
  <a href="#download">Download</a> •
  <a href="#credits">Credits</a> •
  <a href="#related">Related</a> •
  <a href="#license">License</a>
</p>



## Key Features

* TBD

## Setup

TBD

## Usage guide

TBD


## Download

TBD

## Credits

This software uses the following open source packages:

- [scikit-learn](https://sklearn.org)
- [NumPy](https://numpy.org)


## Related

TBD

## Support

<a href="https://buymeacoffee.com/danielpuente" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/purple_img.png" alt="Buy Me A Coffee" style="height: 41px !important;width: 174px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;-webkit-box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>



## License

MIT

---

> GitHub [@dpr1005](https://github.com/dpr1005) &nbsp;&middot;&nbsp;
> Twitter [@callmednx](https://twitter.com/callmednx) &nbsp;&middot;&nbsp;
> LinkedIn [Daniel Puente Ramírez](https://www.linkedin.com/in/danielpuenteramirez/)

